@@ -2,17 +2,21 @@
 #
 # __init__.py - The indexed_gzip namespace.
 #
-# Author: Paul McCarthy <pauldmccarthy@gmail.com>
-#
 """The indexed_gzip namespace. """
 
 
 from .indexed_gzip import (_IndexedGzipFile,     # noqa
                            IndexedGzipFile,
-                           SafeIndexedGzipFile,
+                           open,
                            NotCoveredError,
                            NoHandleError,
                            ZranError)
 
 
-__version__ = '0.8.6'
+SafeIndexedGzipFile = IndexedGzipFile
+"""Alias for ``IndexedGzipFile``, to preserve compatibility with older
+versions of ``nibabel``.
+"""
+
+
+__version__ = '1.6.4'
